@@ -1,5 +1,5 @@
 __author__ = "desultory"
-__version__ = "2.2.3"
+__version__ = "2.2.4"
 
 from collections import UserDict
 from pathlib import Path
@@ -7,7 +7,8 @@ from queue import Queue
 from tomllib import TOMLDecodeError, load
 
 from zenlib.logging import loggify
-from zenlib.util import NoDupFlatList, handle_plural, pretty_print
+from zenlib.types import NoDupFlatList
+from zenlib.util import colorize, handle_plural, pretty_print
 
 
 @loggify
@@ -39,7 +40,7 @@ class InitramfsConfigDict(UserDict):
         # Define the default parameters
         for parameter, default_type in self.builtin_parameters.items():
             if default_type == NoDupFlatList:
-                self.data[parameter] = default_type(no_warn=True, log_bump=5, logger=self.logger)
+                self.data[parameter] = default_type(no_warn=True, _log_bump=5, logger=self.logger)
             else:
                 self.data[parameter] = default_type()
         if not NO_BASE:
@@ -61,7 +62,7 @@ class InitramfsConfigDict(UserDict):
 
     def __setitem__(self, key: str, value) -> None:
         if self["validated"]:
-            return self.logger.error("[%s] Config is validatied, refusing to set value: %s" % (key, value))
+            return self.logger.error("[%s] Config is validated, refusing to set value: %s" % (key, colorize(value, "red")))
         # If the type is registered, use the appropriate update function
         if any(key in d for d in (self.builtin_parameters, self["custom_parameters"])):
             return self.handle_parameter(key, value)
@@ -150,7 +151,7 @@ class InitramfsConfigDict(UserDict):
 
         match parameter_type.__name__:
             case "NoDupFlatList":
-                self.data[parameter_name] = NoDupFlatList(no_warn=True, log_bump=5, logger=self.logger)
+                self.data[parameter_name] = NoDupFlatList(no_warn=True, _log_bump=5, logger=self.logger)
             case "list" | "dict":
                 self.data[parameter_name] = parameter_type()
             case "bool":
@@ -214,14 +215,17 @@ class InitramfsConfigDict(UserDict):
 
             if import_type not in self["imports"]:
                 self.logger.log(5, "Creating import type: %s" % import_type)
-                self["imports"][import_type] = NoDupFlatList(log_bump=10, logger=self.logger)
+                self["imports"][import_type] = NoDupFlatList(_log_bump=10, logger=self.logger)
 
             if import_type == "custom_init":
                 if self["imports"]["custom_init"]:
                     raise ValueError("Custom init function already defined: %s" % self["imports"]["custom_init"])
                 else:
                     self["imports"]["custom_init"] = function_list[0]
-                    self.logger.info("Registered custom init function: %s" % function_list[0].__name__)
+                    self.logger.info(
+                        "Registered custom init function: %s"
+                        % colorize(function_list[0].__name__, "magenta", bold=True)
+                    )
                     continue
 
             if import_type == "funcs":
@@ -242,15 +246,12 @@ class InitramfsConfigDict(UserDict):
 
     @handle_plural
     def _process_modules(self, module: str) -> None:
-        """
-        processes a single module into the config
-        takes list with decorator
-        """
+        """ processes a single module into the config """
         if module in self["modules"]:
             self.logger.debug("Module '%s' already loaded" % module)
             return
 
-        self.logger.info("Processing module: %s" % module)
+        self.logger.info("Processing module: %s" % colorize(module, bold=True))
 
         module_subpath = module.replace(".", "/") + ".toml"
 
@@ -293,7 +294,7 @@ class InitramfsConfigDict(UserDict):
     def validate(self) -> None:
         """Validate config, checks that all values are processed, sets validated flag."""
         if self["_processing"]:
-            self.logger.critical("Unprocessed config values: %s" % ", ".join(list(self["_processing"].keys())))
+            self.logger.critical("Unprocessed config values: %s" % colorize(", ".join(list(self["_processing"].keys()), "red", bold=True)))
         self["validated"] = True
 
     def __str__(self) -> str:
